// Lookup Service interface which retrieves information from the database
// which is then sent to the client.
// Authors:
// Cameron Hayes
// Mac ...
// Elias Sarraf

unit Lookup.Service;

interface

uses
  XData.Service.Common,
  Aurelius.Mapping.Attributes,
  System.JSON,
  System.Generics.Collections,
  System.Classes;

const
  API_MODEL = 'Api';

type

  TUserItem = class
  public
    userID: string;
    username: string;
    password: string;
    full_name: string;
    status: string;
    email_address: string;
    Atype: string;
    rights: integer;
    perspectiveID: string;
    QBID: string;
  end;

  TUserList = class
  public
    count: integer;
    data: TList<TUserItem>;
  end;

  TItemItem = class
  public
    ID: string;
    name: string;
    description: string;
    status: string;
  end;

  TItemList = class
  public
    count: integer;
    data: TList<TItemItem>;
  end;

  TOrderItem = class
  public
     ID: string;
     companyName: string;
     jobName: string;
     orderDate: string;
     proofDue: string;
     proofDone: string;
     artDue: string;
     artDone: string;
     plateDue: string;
     plateDone: string;
     mountDue: string;
     mountDone: string;
     shipDue: string;
     shipDone: string;
     price: string;
     qbRefNum: string;
     colors: string;
  end;

  TOrderList = class
  Public
    count: integer;
    data: TList<TOrderItem>
  end;

  TFullOrder = class
  Public
      //Company
      companyName: string;
      accountCompanyName: string;
      inQuickBooks: string;

      // Staff Fields:
      orderDate: string;
      proofDate: string;
      shipDate: string;
      shipVia: string;
      Quantity: string;
      price: string;
      invoiceTo: string;
      shipTo: string;
      poNumber: string;
      jobName: string;
      quickBooksItem: string;
      artDue: string;
      plateDue: string;
      mountDue: string;
      artLocation: string;

      // Supplied by Customer:
      bwCopy: boolean;
      colorCopy: boolean;
      plates: boolean;
      sampleCarton: boolean;
      dimensionalLayout: string;
      diskOrCD: boolean;
      email: string;
      ftp: string;
      other: string;
      existingCuttingDie: string;
      refArtPrintCard: string;
      refArtAPDF: string;

      // Layout
      rscl: string;
      rscw: string;
      rscd: string;
      dieCutNo: string;
      acrossNo: string;
      aroundNo: string;
      cadFile: string;
      excalliburDie: boolean;
      rscStyle: string;

      // Mounting
      loose: string;
      stickyBak: boolean;
      fullMount: boolean;
      stripMount: string;
      standardSetup: string;
      customBacking: string;
      customAdhesive: string;

       // Colors
       cylinderSize: string;
       machineIdent: string;
       crossHairs: string;
       clemson: string;
       colors: string;

       // Proofing
       fax: string;
       faxAttn: string;
       proofEmail: string;
       emailAttn: string;
       proofShipTo: string;
       fullSizePanel: boolean;
       printCard: boolean;
       wideFormat: boolean;
       pdfFile: boolean;
       proofOther: string;
       artApprovedAsIs: boolean;
       approvedDate: string;

       // Plates
       thickness: string;
       plateMaterial: string;
       jobNumber: string;

       // General
       specialInstructions: string;

  end;



type
  [ServiceContract]
  ILookupService = interface(IInvokable)
    ['{F24E1468-5279-401F-A877-CD48B44F4416}']
    [HttpGet] function Search(phoneNum: string): TOrderList;
    [HttpGet] function GetUsers(searchOptions: string): TUserList;
    [HttpGet] function GetItems(searchOptions: string): TItemList;
    [HttpGet] function GetOrders(searchOptions: string): TOrderList;
    [HttpGet] function GetOrder(orderInfo: string): TFullOrder;

    function AddUser(userInfo: string): string;
    function AddItem(itemInfo: string): string;
    function DelUser(username: string): string;
    function EditUser(const editOptions: string): string;
  end;

implementation

initialization
  RegisterServiceType(TypeInfo(ILookupService));

end.
